@@ -19,16 +19,18 @@ test_that("list_package_resources returns the right output formats.", {
   expect_is(output$id, "character")
 })
 
-test_that("list_package_resources returns a zero row tibble when the package has no resources.", {
-  skip_on_cran()
-  skip_if_offline()
-  output <- list_package_resources("8c1f526a-aa13-49af-80bc-69a1c7e3b2ad")
-  expect_equal(nrow(output), 0)
-})
+# There are no packages with 0 resources anymore
+# test_that("list_package_resources returns a zero row tibble when the package has no resources.", {
+#   skip_on_cran()
+#   skip_if_offline()
+#   output <- list_package_resources("8c1f526a-aa13-49af-80bc-69a1c7e3b2ad")
+#   expect_equal(nrow(output), 0)
+# })
 
 test_that("list_package_resources errors if offline", {
-  with_mock(
-    "curl::has_internet" = function() FALSE,
-    expect_error(list_package_resources("263f54b6-5c60-434f-8958-4e11248f08ff"), "does not work offline")
+  with_mocked_bindings(
+    has_internet = function() FALSE,
+    .package = "curl",
+    code = expect_error(list_package_resources("263f54b6-5c60-434f-8958-4e11248f08ff"), "does not work offline")
   )
 })
